pub struct TransferChunk {
pub chunk_index: u32,
pub data: Vec<u8>,
pub checksum: u32,
}Expand description
A single chunk of data in a block transfer.
Fields
chunk_index: u32Zero-based index of this chunk in the overall transfer.
data: Vec<u8>Raw bytes of this chunk.
checksum: u32Simple checksum: XOR of all bytes cast to u32.
Implementations
Sourceimpl TransferChunk
impl TransferChunk