pub struct CertPinStore { /* private fields */ }Expand description
Thread-safe store for peer certificate fingerprint pins.
Verification Semantics
| Policy | Unknown peer | Fingerprint matches | Fingerprint mismatch |
|---|---|---|---|
| TrustOnFirstUse | PinnedNew (pin + accept) | Accepted | Mismatch |
| Strict | UnknownPeer (reject) | Accepted | Mismatch |
| Observe | Accepted | Accepted | Accepted (+counter) |
Implementations
Sourceimpl CertPinStore
impl CertPinStore
Sourcepub fn pin(
&self,
peer_id: impl Into<String>,
fingerprint: CertFingerprint,
now_ms: u64,
)
pub fn pin( &self, peer_id: impl Into<String>, fingerprint: CertFingerprint, now_ms: u64, )
Pre-register a trusted fingerprint for a peer.
If the peer is already pinned this call is a no-op (existing pin preserved).
Sourcepub fn unpin(&self, peer_id: &str) -> bool
pub fn unpin(&self, peer_id: &str) -> bool
Remove a pinned peer.
Returns true if a pin was present and removed.
Sourcepub fn verify(
&self,
peer_id: &str,
fingerprint: &CertFingerprint,
now_ms: u64,
) -> VerificationResult
pub fn verify( &self, peer_id: &str, fingerprint: &CertFingerprint, now_ms: u64, ) -> VerificationResult
Verify a peer’s certificate fingerprint against the current policy.
Sourcepub fn get_pin(&self, peer_id: &str) -> Option<PeerCertPin>
pub fn get_pin(&self, peer_id: &str) -> Option<PeerCertPin>
Retrieve the pin info for a peer, if any.
Sourcepub fn pinned_peers(&self) -> Vec<String>
pub fn pinned_peers(&self) -> Vec<String>
Return a list of all pinned peer IDs.
Sourcepub fn mismatch_count(&self) -> u64
pub fn mismatch_count(&self) -> u64
Total fingerprint mismatches detected across all verifications.
Sourcepub fn tofu_count(&self) -> u64
pub fn tofu_count(&self) -> u64
Total TOFU pins created.
Sourcepub fn export_pins(&self) -> Vec<PeerCertPin>
pub fn export_pins(&self) -> Vec<PeerCertPin>
Export all pins as a serializable vector.
Sourcepub fn import_pins(&self, pins: Vec<PeerCertPin>)
pub fn import_pins(&self, pins: Vec<PeerCertPin>)
Import pins (merge). Existing pins are not overwritten.