pub struct RoutingStats {
pub cache_hits: u64,
pub cache_misses: u64,
pub stale_routes: u64,
pub total_routes: usize,
}Expand description
Aggregate statistics for the routing optimizer.
Fields
cache_hits: u64Number of lookups that were served from cache
cache_misses: u64Number of lookups that were not in cache (or were stale)
stale_routes: u64Cumulative number of stale entries that have been evicted
total_routes: usizeCurrent number of entries held in the cache
Implementations