pub enum RoutingRecommendation {
RefreshBucket(u8),
EvictPeer {
bucket: u8,
peer_id: String,
},
PingPeer {
bucket: u8,
peer_id: String,
},
NoAction,
}Expand description
Remediation action recommended by the optimizer.
Variants
RefreshBucket(u8)
Trigger a Kademlia lookup to populate a sparse bucket.
EvictPeer
Remove a stale / confirmed-unresponsive peer from the routing table.
PingPeer
Send a liveness ping before deciding whether to evict.
NoAction
No action required.
Implementations
Sourceimpl RoutingRecommendation
impl RoutingRecommendation
Sourcepub fn is_actionable(&self) -> bool
pub fn is_actionable(&self) -> bool
Returns true if this recommendation requires an action to be taken
(i.e. is not RoutingRecommendation::NoAction).