Module event_bus

Module event_bus 

NetworkEventBus — synchronous in-process publish-subscribe bus for network events.

Decouples protocol handlers from application logic by providing a simple, zero-dependency pub/sub mechanism with per-subscriber event queues and configurable event filtering.

Structs

BusStats
Aggregate statistics for the NetworkEventBus.
NetworkEventBus
Synchronous in-process publish-subscribe bus for NetworkEvents.
Subscription
A single subscription to the NetworkEventBus.

Enums

EventFilter
Determines which events a subscription will receive.
NetworkEvent
All events that can be emitted by the network layer.