pub struct GossipState {
pub seen: HashMap<String, u64>,
}Expand description
Tracks the highest sequence number seen from each peer to deduplicate messages.
Fields
seen: HashMap<String, u64>Maps peer_id → highest sequence observed so far.
Implementations
Sourceimpl GossipState
impl GossipState
Sourcepub fn is_new(&self, peer_id: &str, sequence: u64) -> bool
pub fn is_new(&self, peer_id: &str, sequence: u64) -> bool
Returns true when sequence is strictly greater than the last recorded value
for peer_id (or when the peer has never been seen).
Sourcepub fn record(&mut self, peer_id: &str, sequence: u64)
pub fn record(&mut self, peer_id: &str, sequence: u64)
Advance (or initialise) the tracked sequence for peer_id.
Only updates when sequence is greater than the currently stored value.
Sourcepub fn prune_stale(&mut self, threshold_seq: u64)
pub fn prune_stale(&mut self, threshold_seq: u64)
Remove all peers whose highest recorded sequence is ≤ threshold_seq.
Useful for cleaning up stale entries from long-gone peers.