pub struct AuthStats {
pub messages_signed: u64,
pub messages_verified: u64,
pub replay_attacks_blocked: u64,
pub expired_key_rejections: u64,
pub invalid_signature_rejections: u64,
}Expand description
Cumulative counters collected by MessageAuthenticator.
Fields
messages_signed: u64Total messages successfully signed.
messages_verified: u64Total messages successfully verified.
replay_attacks_blocked: u64Number of messages blocked due to replay detection.
expired_key_rejections: u64Number of verification failures caused by an expired key.
invalid_signature_rejections: u64Number of verification failures caused by a bad signature.