pub struct NatTraversalConfig {
pub stun_timeout_ms: u64,
pub max_punch_attempts: u32,
pub punch_interval_ms: u64,
pub port_prediction_range: u16,
pub enable_upnp: bool,
pub enable_relay_fallback: bool,
}Expand description
Configuration for NAT traversal behaviour
Fields
stun_timeout_ms: u64Timeout for STUN binding requests (ms)
max_punch_attempts: u32Maximum hole-punch attempts per peer
punch_interval_ms: u64Interval between successive punch packets (ms)
port_prediction_range: u16Range of ports to scan around a predicted port
enable_upnp: boolWhether to attempt UPnP port mapping
enable_relay_fallback: boolWhether to fall back to relay when punch fails