pub struct CircuitCallGuard {
pub issued_at: u64,
/* private fields */
}Expand description
An RAII guard returned by NetworkCircuitBreaker::call.
Drop the guard without calling CircuitCallGuard::record and a
CircuitOutcome::Timeout is automatically recorded. This ensures that
abandoned in-flight requests are always accounted for.
Fields
issued_at: u64Timestamp at which the call was issued (µs).
Implementations
Sourceimpl CircuitCallGuard
impl CircuitCallGuard
Sourcepub fn mark_recorded(&mut self)
pub fn mark_recorded(&mut self)
Mark the guard as having been explicitly recorded so that the Drop
implementation does not fire a spurious Timeout.
Sourcepub fn is_recorded(&self) -> bool
pub fn is_recorded(&self) -> bool
Returns true if an explicit outcome has already been recorded.