pub struct PfaFragment {
pub msg_id: PfaMessageId,
pub fragment_index: u32,
pub total_fragments: u32,
pub offset: usize,
pub data: Vec<u8>,
pub checksum: u32,
}Expand description
A single fragment of a fragmented message.
Fields
msg_id: PfaMessageIdMessage this fragment belongs to.
fragment_index: u32Zero-based index of this fragment within the message.
total_fragments: u32Total number of fragments that constitute the full message.
offset: usizeByte offset of this fragment within the original message.
data: Vec<u8>Payload bytes.
checksum: u32FNV-1a low-32 checksum of data.