pub struct PeerCapability {
pub name: String,
pub version: CapabilityVersion,
pub required: bool,
pub metadata: HashMap<String, String>,
}Expand description
A single named capability with version and optional metadata key-value pairs.
When required is true, the local peer considers this capability mandatory
for a successful negotiation (subject to the active CapabilityPolicy).
Fields
name: StringProtocol identifier, e.g. "bitswap" or "graphsync".
version: CapabilityVersionVersion triple describing the capability’s feature level.
required: boolWhether the local node considers this capability mandatory.
metadata: HashMap<String, String>Arbitrary string key-value pairs (e.g. "max_block_size" → "1048576").
Implementations
Sourceimpl PeerCapability
impl PeerCapability
Sourcepub fn required(name: impl Into<String>, version: CapabilityVersion) -> Self
pub fn required(name: impl Into<String>, version: CapabilityVersion) -> Self
Construct a required capability with no metadata.
Sourcepub fn optional(name: impl Into<String>, version: CapabilityVersion) -> Self
pub fn optional(name: impl Into<String>, version: CapabilityVersion) -> Self
Construct an optional capability with no metadata.
Sourcepub fn with_metadata(
name: impl Into<String>,
version: CapabilityVersion,
required: bool,
metadata: HashMap<String, String>,
) -> Self
pub fn with_metadata( name: impl Into<String>, version: CapabilityVersion, required: bool, metadata: HashMap<String, String>, ) -> Self
Construct a capability with metadata.