Module routing_auditor

Module routing_auditor 

Routing Table Auditor

Audits the DHT routing table for health issues including stale entries, bucket imbalances, and unreachable peers.

Structs

AuditFinding
A single finding produced by a routing-table audit run.
AuditorConfig
Configuration for the RoutingTableAuditor.
BucketInfo
Information about a single Kademlia k-bucket.
RoutingTableAuditor
Audits a DHT routing table represented as a collection of BucketInfo entries and produces AuditFinding items describing any health issues.

Enums

AuditSeverity
Severity level of an audit finding.

Constants

DEFAULT_MAX_CAPACITY
Default k-bucket capacity as defined by the Kademlia paper.