pub struct NodeId(pub [u8; 32]);Expand description
256-bit node identifier used for XOR-distance routing.
Tuple Fields
0: [u8; 32]Implementations
Sourceimpl NodeId
impl NodeId
Sourcepub fn xor_distance(&self, other: &NodeId) -> [u8; 32]
pub fn xor_distance(&self, other: &NodeId) -> [u8; 32]
Compute byte-wise XOR distance between self and other.
Sourcepub fn leading_zeros(&self) -> u32
pub fn leading_zeros(&self) -> u32
Count the number of leading zero bits in the raw bytes.
This is used as the Kademlia bucket index.
Sourcepub fn from_str_hex(s: &str) -> Option<NodeId>
pub fn from_str_hex(s: &str) -> Option<NodeId>
Parse a 64-character lower-case hex string into a NodeId.
Returns None if the string is not exactly 64 hex characters.