pub enum StreamPriority {
Background = 0,
Low = 1,
Normal = 2,
High = 4,
Critical = 8,
}Expand description
Priority level for a logical stream.
Higher priority streams are dequeued first by the multiplexer. Within the same priority, frames are emitted in FIFO order.
Variants
Background = 0
Best-effort delivery — weight 0.
Low = 1
Low priority — weight 1.
Normal = 2
Normal priority — weight 2.
High = 4
High priority — weight 4.
Critical = 8
Critical (real-time) — weight 8.
Implementations