pub struct MuxStats {
pub total_streams: usize,
pub open_streams: usize,
pub queued_frames: usize,
pub total_frames_sent: u64,
pub total_frames_received: u64,
pub total_bytes_sent: u64,
}Expand description
Compact snapshot of StreamMultiplexer statistics (original form).
Fields
total_streams: usizeTotal streams ever opened (including currently open ones).
open_streams: usizeNumber of streams currently in the StreamState::Open state.
queued_frames: usizeFrames currently waiting in the send queue.
total_frames_sent: u64Total frames that have been dequeued and handed to the caller.
total_frames_received: u64Total frames that have been processed via StreamMultiplexer::receive.
total_bytes_sent: u64Total payload bytes that have been enqueued for sending across all streams.