Content Routing Optimizer
Optimizes content routing decisions by maintaining a cost model for fetching blocks from different peers, caching routing decisions, and detecting when cached routes have become stale.
Structs
- Content
Routing Optimizer - Content routing optimizer that caches and manages peer routing decisions.
- Optimizer
Config - Configuration knobs for the
ContentRoutingOptimizer. - Route
Cost - Cost model for fetching content from a specific peer.
- Route
Entry - A cached routing entry for a single CID.
- Routing
Stats - Aggregate statistics for the routing optimizer.