NetworkEventBus — synchronous in-process publish-subscribe bus for network events.
Decouples protocol handlers from application logic by providing a simple, zero-dependency pub/sub mechanism with per-subscriber event queues and configurable event filtering.
Structs
- BusStats
- Aggregate statistics for the
NetworkEventBus. - Network
Event Bus - Synchronous in-process publish-subscribe bus for
NetworkEvents. - Subscription
- A single subscription to the
NetworkEventBus.
Enums
- Event
Filter - Determines which events a subscription will receive.
- Network
Event - All events that can be emitted by the network layer.